@@ -1,6 +1,5 @@
-
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
+# Copyright (C) 2005-2015 by Jörn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -10,6 +9,8 @@
 package Event::RPC::Logger;
 
 use strict;
+use utf8;
+
 use FileHandle;
 
 sub get_filename                { shift->{filename}                     }
@@ -124,7 +125,7 @@ sub remove_fh {
 
 __END__
 
-=encoding latin1
+=encoding utf8
 
 =head1 NAME
 
@@ -199,11 +200,11 @@ Removes a filehandle.
 
 =head1 AUTHORS
 
-  Jrn Reder <joern at zyn dot de>
+  Jörn Reder <joern AT zyn.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
+Copyright (C) 2005-2015 by Jörn Reder <joern AT zyn.de>.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
