@@ -325,7 +325,7 @@ sub setup_auth_module {
     1;
 }
 
-sub start {
+sub prepare {
     my $self = shift;
 
     $self->setup_listeners
@@ -341,6 +341,15 @@ sub start {
         )
     );
 
+    1;
+}
+
+sub start {
+    my $self = shift;
+
+    #-- Prepare server for startup
+    $self->prepare;
+
     my $loop = $self->get_loop;
 
     $self->log ("Enter main loop using ".ref($loop));
@@ -566,8 +575,13 @@ Event::RPC::Server - Simple API for event driven RPC servers
   );
 
   $server->set_max_packet_size(2*1024*1024*1024);
+
+  # start server and event loop
   $server->start;
 
+  # or prepare server start if you like to control event loop by yourself
+  $server->prepare;
+
   # and later from inside your server implementation
   Event::RPC::Server->instance->stop;
 
